@@ -5,7 +5,7 @@
 #' distribution with modified likelihood to induce homogeneity across
 #' neighboring observations. The model can segment the observations into
 #' multiple clusters characterized by different
-#' intrinsic dimensions, which allows to capture hidden patterns in the data.
+#' intrinsic dimensions. This permits to capture hidden patterns in the data.
 #' For more details on the algorithm, refer to
 #' \href{https://www.nature.com/articles/s41598-020-72222-0}{Allegra et al., 2020}.
 #' For an example of application to basketball data, see
@@ -19,10 +19,11 @@
 #' @param thinning integer indicating the thinning interval.
 #' @param verbose logical, should the progress of the sampler be printed?
 #' @param q integer, first local homogeneity parameter. Default is 3.
-#' @param xi real between 0 and 1, second local homogeneity parameter.
+#' @param xi real number between 0 and 1, second local homogeneity parameter.
 #' Default is 0.75.
-#' @param alpha_Dirichlet parameter of the Dirichlet prior on the mixture
-#' weights. Default is 0.05, inducing a sparse mixture.
+#' @param alpha_Dirichlet parameter of the symmetric Dirichlet prior
+#' on the mixture weights. Default is 0.05, inducing a sparse mixture.
+#' Values that are too small (i.e., lower than 0.005) may cause underflow.
 #' @param a0_d shape parameter of the Gamma prior on \code{d}.
 #' @param b0_d rate parameter of the Gamma prior on \code{d}.
 #' @param prior_type character, type of Gamma prior on \code{d}, can be
@@ -64,13 +65,12 @@
 #' Allegra M, Facco E, Denti F, Laio A, Mira A (2020).
 #' “Data segmentation based on the local intrinsic dimension.”
 #' Scientific Reports, 10(1), 1–27. ISSN 20452322,
-#' doi: 10.1038/s41598-020-72222-0, 1902.10459,
-#' \url{https://arxiv.org/abs/1902.10459}
+#' \doi{10.1038/s41598-020-72222-0, 1902.10459},
 #'
 #' Santos-Fernandez E, Denti F, Mengersen K, Mira A (2021).
 #' “The role of intrinsic dimension in high-resolution player tracking data –
 #' Insights in basketball.” Annals of Applied Statistics - Forthcoming, –
-#' ISSN 2331-8422, 2002.04148, \url{https://arxiv.org/abs/2002.04148}
+#' ISSN 2331-8422, 2002.04148, \doi{10.1038/s41598-022-20991-1}
 #'
 #' @examples
 #' \donttest{
@@ -155,7 +155,18 @@ Hidalgo <- function(X  = NULL,
 
   IRC.list <-  index_row_col(Nq, q, n)
   rm(Nq)
-  pl    <- MCMCpack::rdirichlet(K, alpha_Dirichlet)
+
+  pl  <- c(MCMCpack::rdirichlet(1, rep(alpha_Dirichlet,K)))
+  # in case alpha_Dirichlet is too low, initialize as equiprobable
+  if( any(is.na(pl)) ){
+
+    warning(paste("alpha_Dirichlet is too low and caused underflows when initializing.
+Consider increasing its value in the next run."),
+            call. = FALSE)
+
+    pl <-  rep(alpha_Dirichlet,K)
+  }
+
   Ci    <- sample(K, n, TRUE, pl)
   d     <- stats::rgamma(K, a0_d, 1 / b0_d)
 
@@ -212,7 +223,7 @@ Hidalgo <- function(X  = NULL,
       log_Precomp_ratios = log_corr
     )
 
-    # STEP 2, uptading Pi^*
+    # STEP 2, updating Pi^*
 
     Ci     <- factor(Ci, levels = seq_len(K))
     N_Slog <- Groups_quantities(mu_obser = mus,
@@ -327,9 +338,10 @@ Hidalgo <- function(X  = NULL,
     Q.95 = sd4,
     OBS = seq_len(n)
   )
-  if (verbose)
+  if (verbose){
     cat("Done! \n")
-
+    close(pbar)
+  }
   output <- list(
     cluster_prob         = cluster_prob,
     membership_labels    = membership_labels,
@@ -338,7 +350,6 @@ Hidalgo <- function(X  = NULL,
     id_summary           = summa,
     recap                = Recap
   )
-  close(pbar)
   structure(output, class = c("Hidalgo", class(output)))
 
 }
