@@ -21,7 +21,7 @@
 #' @references
 #' Facco E, D'Errico M, Rodriguez A, Laio A (2017). "Estimating the intrinsic
 #' dimension of datasets by a minimal neighborhood information."
-#' Scientific Reports, 7(1), 1-8.
+#' Scientific Reports, 7(1).
 #' ISSN 20452322, doi: 10.1038/s41598-017-11873-y.
 #'
 twonn_linfit <- function(mus,
@@ -100,7 +100,7 @@ summary.twonn_linfit <- function(object, ...) {
 #' @export
 print.summary.twonn_linfit <- function(x, ...) {
   cat("Model: TWO-NN\n")
-  cat("Method: Least Square Estimation\n")
+  cat("Method: Least Squares Estimation\n")
   cat(paste0(
     "Sample size: ",
     x[1],
